@@ -1,41 +1,42 @@
 #
-from .util import timer, hub_authenticated, HubException
-from dateutil.parser import parse
-from datetime import datetime, timedelta
-from requests.structures import CaseInsensitiveDict
-from gql import gql, Client
-from gql.transport.requests import RequestsHTTPTransport
+import ast
 import io
 import json
 import os
+import time
+import uuid
+from datetime import datetime, timedelta
+from math import nan
+from typing import List, Union
+from urllib.parse import parse_qs, urlparse
+
+import ipywidgets as widgets
+import markdown
 import numpy as np
 import pandas as pd
-from typeguard import typechecked
-from typing import List, Union
 import pkg_resources
 import requests
-from math import nan
-
-import markdown
-import ipywidgets as widgets
+from dateutil.parser import parse
+from gql import Client, gql
+from gql.transport.requests import RequestsHTTPTransport
 from ipywidgets import HTML
-import uuid
-from . import __version__
-
-from .queries import *
-from .access import save_jwt, delete_jwt, restore_previous_jwt, get_previous_jwt
-from urllib.parse import urlparse, parse_qs
+from requests.structures import CaseInsensitiveDict
+from typeguard import typechecked
 from urllib3.exceptions import HTTPError
-import time
-import ast
+
+from . import __version__
+from .access import delete_jwt, get_previous_jwt, restore_previous_jwt, save_jwt
+from .queries import *
+from .util import HubException, hub_authenticated, timer
 
 # import urllib3
 # urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 HUB_BASE_URL = "https://data.academic.osisoft.com"
-AUTH_ENDPOINT = f"{HUB_BASE_URL}/auth"
-GRAPHQL_ENDPOINT = f"{HUB_BASE_URL}/graphql2"
 REGISTRATION_URL = "https://academic.osisoft.com/register"
+AUTH_ENDPOINT = "https://academichub-auth.azurewebsites.net/auth"
+GRAPHQL_ENDPOINT = "https://academichub-gw.azurewebsites.net/graphql"
+
 MAX_STORED_DV_ROWS = 2000000
 UXIE_CONSTANT = 100 * 1000
 
@@ -58,6 +59,7 @@ stream_queries = {
     "stream": q_stream,
     "data": q_stream_data,
     "ends": q_stream_ends,
+    "interpolated": q_stream_interpolated,
 }
 
 
@@ -547,7 +549,7 @@ class HubClient:
         dataview_f = self.__get_data_stored if stored else self.__get_data_interpolated
         dataview_id = remap_campus_dataview_id(dataview_id)
 
-        delay_502 = 1
+        delay_50x = 1
         while True:
             try:
                 # print(f"[{next_page}]", end="")
@@ -598,11 +600,11 @@ class HubClient:
                 if "409" in str(e):
                     print("#", end="")
                     continue
-                if "502" in str(e):
+                if "502" in str(e): #  or "504" in str(e):
                     print("[@]", end="")
-                    time.sleep(delay_502)
-                    delay_502 *= 2
-                    if delay_502 > 8:
+                    time.sleep(delay_50x)
+                    delay_50x *= 2
+                    if delay_50x > 8:
                         raise e
                     continue
                 if "408" not in str(e):
@@ -683,7 +685,9 @@ class HubClient:
 
     @hub_authenticated
     @typechecked
-    def get_streams(self, namespace: str, query: str = "", count: int = 0, skip: int = 0):
+    def get_streams(
+        self, namespace: str, query: str = "", count: int = 0, skip: int = 0
+    ):
         args = dict(count=2000)
         if query:
             args["query"] = query
@@ -721,9 +725,47 @@ class HubClient:
         )
         df = pd.DataFrame(reply["namespaces"][0]["data"])
         if len(df) > 0:
-            df["Time"] = pd.to_datetime(df["Time"])
+            time_column = list(df.columns)[0]
+            df[time_column] = pd.to_datetime(df[time_column])
             if column_name:
-                df.columns = ["Time", column_name]
+                df.columns = [time_column, column_name]
+        return df
+
+    @hub_authenticated
+    @typechecked
+    def stream_interpolated_pd(
+        self,
+        namespace: str,
+        stream_id,
+        start: str,
+        end: str,
+        interval: str,
+        column_name: str = "",
+        raw: bool = False,
+    ):
+        try:
+            t_interval = datetime.strptime(interval, "%H:%M:%S")
+            delta = t_interval - parse("1900-01-01")
+            count = int((parse(end) - parse(start)) / delta) + 1
+        except ValueError as e:
+            raise GraphQLException(
+                f"@Error: start, end or interval (HH:MM:SS) has invalid format: {e}"
+            ) from None
+
+        reply = self.__stream_ops(
+            "interpolated",
+            namespace,
+            stream_id,
+            dict(start=start, end=end, count=count),
+        )
+        df = pd.DataFrame(reply["namespaces"][0]["data"])
+        if len(df) > 0:
+            time_column = list(df.columns)[0]
+            df[time_column] = pd.to_datetime(df[time_column])
+            if not raw:
+                df = df.drop(df.columns[2:], axis=1)
+            if column_name:
+                df.columns = [df.columns[0], column_name] + list(df.columns[2:])
         return df
 
     @hub_authenticated
